@@ -353,6 +353,12 @@ class Node(BaseModel):
         set_d: GQL_D = set_patch.dict(exclude_unset=True)
         remove_d: GQL_D = remove_patch.dict(exclude_unset=True)
 
+        # stringify values before you include relationships which should not be stringified -> as long as they are REFS
+        # i can see this being a problem if you're adding an embedded obj as a Ref ->
+        # will deal w that when it comes later
+        set_d = self.objs_to_str(set_d)
+        remove_d = self.objs_to_str(remove_d)
+
         # now add relationship fields
         rel_set_d = self.make_gql_d_from_rel_d_input(rel_d_input=to_set or {})
         rel_remove_d = self.make_gql_d_from_rel_d_input(rel_d_input=to_remove or {})
@@ -372,6 +378,43 @@ class Node(BaseModel):
             to_set={}, to_remove={}, given_resolver=given_resolver
         )
 
+    @classmethod
+    async def update_many(
+        cls: T.Type[NodeModel],
+        *,
+        nodes: T.List[NodeModel],
+        set_d: dict = None,
+        remove_d: dict = None,
+        given_resolver: ResolverType = None,
+    ) -> bool:
+        if not set_d and not remove_d:
+            return False
+        variables = {
+            "set": jsonable_encoder(set_d) if set_d else {},
+            "remove": jsonable_encoder(remove_d) if remove_d else {},
+            "filter": {cls.GQL.uid_field_name: [node._uid for node in nodes]},
+        }
+        resolver = given_resolver or cls.GQL.resolver()
+        query_str = resolver.make_update_mutation_str()
+        debug(query_str)
+        debug(variables)
+        j = await cls.GQL.dgraph_client.execute(
+            query_str=query_str, variables=variables
+        )
+        node_d_lst = j["data"][f"{cls.GQL.update_function_name}"][
+            cls.GQL.payload_node_name
+        ]
+        if not node_d_lst:
+            # raise Exception("No update was registered!!")
+            print("NO UPDATE WAS REGISTERED")
+            return False
+
+        for og_node, node_d in zip(nodes, node_d_lst):
+            new_node = resolver.parse_obj_nested(node_d)
+            og_node.hydrate(new_node=new_node)
+
+        return True
+
     @classmethod
     async def _add(
         cls: T.Type[NodeModel],
@@ -435,7 +478,8 @@ class Node(BaseModel):
     ) -> bool:
         set_d, remove_d = self.base_set_remove_d(to_set=to_set, to_remove=to_remove)
         # turn base models or dicts into strs
-        # idk why i have this below??? works when commented out
+        """i moved the functions below to inside the function above. This is because relationships should 
+        not be turned to string, but nested values should be"""
         # set_d = self.objs_to_str(set_d)
         # remove_d = self.objs_to_str(remove_d)
         return await self.update_from_set_remove_ds(
